<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Thien Hau <thienhau.9a14@gmail.com>
 * @author James Do <jdo@myrealbox.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Sửa đổi trang này';
$lang['btn_source']            = 'Xem mã nguồn trang';
$lang['btn_show']              = 'Xem trang';
$lang['btn_create']            = 'Tạo trang này';
$lang['btn_search']            = 'Tìm kiếm';
$lang['btn_save']              = 'Lưu';
$lang['btn_preview']           = 'Xem trước';
$lang['btn_top']               = 'Quay lên trên';
$lang['btn_newer']             = '<< mới hơn';
$lang['btn_older']             = 'cũ hơn >>';
$lang['btn_revs']              = 'Phiên bản cũ';
$lang['btn_recent']            = 'Thay đổi gần đây';
$lang['btn_upload']            = 'Tải lên';
$lang['btn_cancel']            = 'Hủy bỏ';
$lang['btn_index']             = 'Sơ đồ trang web';
$lang['btn_secedit']           = 'Sửa đổi';
$lang['btn_login']             = 'Đăng nhập';
$lang['btn_logout']            = 'Đăng xuất';
$lang['btn_admin']             = 'Quản lý';
$lang['btn_update']            = 'Cập nhật';
$lang['btn_delete']            = 'Xóa';
$lang['btn_back']              = 'Quay lại';
$lang['btn_backlink']          = 'Liên kết đến đây';
$lang['btn_subscribe']         = 'Quản lý đăng ký';
$lang['btn_profile']           = 'Cập nhật hồ sơ';
$lang['btn_reset']             = 'Đặt lại';
$lang['btn_resendpwd']         = 'Đặt mật khẩu mới';
$lang['btn_draft']             = 'Sửa đổi bản nháp';
$lang['btn_recover']           = 'Phục hồi bản nháp';
$lang['btn_draftdel']          = 'Xóa bản nháp';
$lang['btn_revert']            = 'Phục hồi';
$lang['btn_register']          = 'Đăng ký';
$lang['btn_apply']             = 'Áp dụng';
$lang['btn_media']             = 'Quản lý phương tiện';
$lang['btn_deleteuser']        = 'Xóa tài khoản của tôi';
$lang['btn_img_backto']        = 'Quay lại %s';
$lang['btn_mediaManager']      = 'Xem trong Quản lý phương tiện';
$lang['loggedinas']            = 'Đã đăng nhập vói tên:';
$lang['user']                  = 'Tên thành viên';
$lang['pass']                  = 'Mật khẩu';
$lang['newpass']               = 'Mật khẩu mới';
$lang['oldpass']               = 'Xác nhận mật khẩu hiện tại';
$lang['passchk']               = 'lần nữa';
$lang['remember']              = 'Nhớ tôi';
$lang['fullname']              = 'Tên thật';
$lang['email']                 = 'Thư điện tử';
$lang['profile']               = 'Hồ sơ thành viên';
$lang['badlogin']              = 'Xin lỗi, tên thành viên hoặc mật khẩu không đúng.';
$lang['badpassconfirm']        = 'Xin lỗi, mật khẩu không đúng';
$lang['minoredit']             = 'Thay đổi nhỏ';
$lang['draftdate']             = 'Bản nháp được lưu tự động lúc';
$lang['nosecedit']             = 'Trang đã được thay đổi trong một thời gian ngắn, thay vào đó thông tin phần đã hết hạn được tải toàn bộ trang.';
$lang['searchcreatepage']      = 'Nếu bạn không tìm thấy những gì bạn đang tìm kiếm, bạn có thể tạo hoặc sửa đổi trang %s, được đặt tên theo truy vấn của bạn.';
$lang['search_fullresults']    = 'Toàn văn kết quả';
$lang['js']['search_toggle_tools'] = 'Chuyển đổi công cụ tìm kiếm';
$lang['js']['willexpire']      = 'Khóa của bạn dùng cho việc sửa đổi trang này sắp hết hạn sau một phút nữa.\nĐể tránh xung đột, hãy sử dụng nút xem trước để đặt lại bộ hẹn giờ khóa.';
$lang['js']['notsavedyet']     = 'Những thay đổi chưa được lưu sẽ bị mất.';
$lang['js']['searchmedia']     = 'Tìm kiếm tập tin';
$lang['js']['keepopen']        = 'Giữ cửa sổ mở trên lựa chọn';
$lang['js']['hidedetails']     = 'Ẩn thông tin chi tiết';
$lang['js']['mediatitle']      = 'Cài đặt liên kết';
$lang['js']['mediadisplay']    = 'Kiểu liên kết';
$lang['js']['mediaalign']      = 'Căn chỉnh';
$lang['js']['mediasize']       = 'Kích thước hình ảnh';
$lang['js']['mediatarget']     = 'Liên kết đến';
$lang['js']['mediaclose']      = 'Đóng';
$lang['js']['mediainsert']     = 'Chèn';
$lang['js']['mediadisplayimg'] = 'Hiển thị hình ảnh.';
$lang['js']['mediadisplaylnk'] = 'Chỉ hiển thị liên kết.';
$lang['js']['mediasmall']      = 'Phiên bản nhỏ';
$lang['js']['mediamedium']     = 'Phiên bản vừa';
$lang['js']['medialarge']      = 'Phiên bản lớn';
$lang['js']['mediaoriginal']   = 'Phiên bản gốc';
$lang['js']['medialnk']        = 'Liên kết tới trang chi tiết';
$lang['js']['mediadirect']     = 'Liên kết trực tiếp tới bản gốc';
$lang['js']['medianolnk']      = 'Không liên kết';
$lang['js']['medianolink']     = 'Không liên kết đến hình ảnh';
$lang['js']['medialeft']       = 'Căn chỉnh hình ảnh sang trái.';
$lang['js']['mediaright']      = 'Căn chỉnh hình ảnh sang phải.';
$lang['js']['mediacenter']     = 'Căn chỉnh hình ảnh ra giữa.';
$lang['js']['medianoalign']    = 'Không căn chỉnh.';
$lang['js']['nosmblinks']      = 'Liên kết đến Windows shares chỉ hoạt động trong Microsoft Internet Explorer.\nBạn vẫn có thể sao chép và dán liên kết.';
$lang['js']['linkwiz']         = 'Thuật sĩ liên kết';
$lang['js']['linkto']          = 'Liên kết đến:';
$lang['js']['del_confirm']     = 'Muốn xóa (các) mục đã chọn?';
$lang['js']['restore_confirm'] = 'Sẵn sàng phục hồi phiên bản này?';
$lang['js']['media_diff']      = 'Xem khác biệt:';
$lang['js']['media_diff_both'] = 'Cạnh nhau';
$lang['js']['media_diff_opacity'] = 'Sáng qua';
$lang['js']['media_diff_portions'] = 'Vuốt';
$lang['js']['media_select']    = 'Chọn tập tin…';
$lang['js']['media_upload_btn'] = 'Tải lên';
$lang['js']['media_done_btn']  = 'Xong';
$lang['js']['media_drop']      = 'Kéo tập tin vào đây để tải lên';
$lang['js']['media_cancel']    = 'xóa';
$lang['js']['media_overwrt']   = 'Ghi đè các tập tin hiện có';
$lang['js']['data_insecure']   = 'CẢNH BÁO: Có vẻ như đường dẫn dữ liệu của bạn không được bảo mật đúng cách. Xin vui lòng đọc <a href="https://www.dokuwiki.org/security#web_access_security">Web Access Security in DokuWiki</a>.';
$lang['search_exact_match']    = 'Khớp chính xác';
$lang['search_starts_with']    = 'Bắt đầu với';
$lang['search_ends_with']      = 'Kết thúc bằng';
$lang['search_contains']       = 'Chứa';
$lang['search_custom_match']   = 'Tùy chỉnh';
$lang['search_any_ns']         = 'Mọi không gian tên';
$lang['search_any_time']       = 'Mọi lúc';
$lang['search_past_7_days']    = 'Tuần trước';
$lang['search_past_month']     = 'Tháng trước';
$lang['search_past_year']      = 'Năm trước';
$lang['search_sort_by_hits']   = 'Sắp xếp theo lượt truy cập';
$lang['search_sort_by_mtime']  = 'Sắp xếp theo sửa đổi cuối';
$lang['regmissing']            = 'Xin lỗi, bạn cần điền vào tất cả các trường';
$lang['reguexists']            = 'Xin lỗi, thành viên có thông tin đăng nhập này đã tồn tại.';
$lang['regsuccess']            = 'Thành viên đã được tạo và mật khẩu đã được gửi qua thư điện tử.';
$lang['regsuccess2']           = 'Thành viên đã được tạo.';
$lang['regfail']               = 'Không thể tạo thành viên.';
$lang['regmailfail']           = 'Có vẻ như đã xảy ra lỗi khi gửi thư mật khẩu. Vui lòng liên hệ với quản trị viên!';
$lang['regbadmail']            = 'Địa chỉ thư điện tử được cung cấp có vẻ không hợp lệ - nếu bạn nghĩ đây là lỗi, hãy liên hệ với quản trị viên';
$lang['regbadpass']            = 'Hai mật khẩu đã nhập không giống nhau, vui lòng thử lại.';
$lang['regpwmail']             = 'Mật khẩu DokuWiki của bạn';
$lang['reghere']               = 'Bạn chưa có tài khoản? Hãy tạo một cái';
$lang['profna']                = 'Wiki này không hỗ trợ sửa đổi hồ sơ';
$lang['profnochange']          = 'Không có thay đổi, không có gì để làm.';
$lang['profnoempty']           = 'Không được bỏ trống tên hoặc địa chỉ thư điện tử.';
$lang['profchanged']           = 'Cập nhật hồ sơ thành viên thành công.';
$lang['profnodelete']          = 'Wiki này không hỗ trợ xóa thành viên';
$lang['profdeleteuser']        = 'Xóa tài khoản';
$lang['profdeleted']           = 'Tài khoản thành viên của bạn đã bị xóa khỏi wiki này';
$lang['profconfdelete']        = 'Tôi muốn xóa tài khoản của tôi khỏi wiki này. <br/> Hành động này không thể hoàn tác.';
$lang['profconfdeletemissing'] = 'Hộp kiểm xác nhận chưa được đánh dấu';
$lang['proffail']              = 'Hồ sơ thành viên chưa được cập nhật.';
$lang['pwdforget']             = 'Bạn quên mật khẩu? Tạo một cái mới';
$lang['resendna']              = 'Wiki này không hỗ trợ gửi lại mật khẩu.';
$lang['resendpwd']             = 'Đặt mật khẩu mới cho';
$lang['resendpwdmissing']      = 'Xin lỗi, bạn phải điền vào tất cả các trường.';
$lang['resendpwdnouser']       = 'Xin lỗi, chúng tôi không thể tìm thấy thành viên này trong cơ sở dữ liệu của chúng tôi.';
$lang['resendpwdbadauth']      = 'Xin lỗi, mã xác thực này không hợp lệ. Hãy chắc chắn rằng bạn đã sử dụng liên kết xác nhận đầy đủ.';
$lang['resendpwdconfirm']      = 'Một liên kết xác nhận đã được gửi qua thư điện tử.';
$lang['resendpwdsuccess']      = 'Mật khẩu mới của bạn đã được gửi qua thư điện tử.';
$lang['license']               = 'Trừ khi có ghi chú khác, nội dung trên wiki này được cấp phép theo giấy phép sau:';
$lang['licenseok']             = 'Lưu ý: Bằng cách sửa đổi trang này, bạn đồng ý cấp phép cho nội dung của mình theo giấy phép sau:';
$lang['searchmedia']           = 'Tìm kiếm tên tập tin:';
$lang['searchmedia_in']        = 'Tìm kiếm trong %s';
$lang['txt_upload']            = 'Chọn tập tin để tải lên:';
$lang['txt_filename']          = 'Tải lên dưới dạng (tùy chọn):';
$lang['txt_overwrt']           = 'Ghi đè tập tin hiện có';
$lang['maxuploadsize']         = 'Tải lên tối đa. %s mỗi tập tin.';
$lang['allowedmime']           = 'Danh sách các phần mở rộng tập tin được phép';
$lang['lockedby']              = 'Hiện đang bị khóa bởi:';
$lang['lockexpire']            = 'Khóa hết hạn vào lúc:';
$lang['rssfailed']             = 'Đã xảy ra lỗi khi tìm nạp nguồn cấp dữ liệu này:';
$lang['nothingfound']          = 'Không có gì được tìm thấy.';
$lang['mediaselect']           = 'Tập tin phương tiện';
$lang['uploadsucc']            = 'Tải lên thành công';
$lang['uploadfail']            = 'Tải lên không thành công. Có thể không đủ quyền?';
$lang['uploadwrong']           = 'Tải lên bị từ chối. Phần mở rộng tập tin này bị cấm!';
$lang['uploadexist']           = 'Tập tin đã tồn tại. Không có gì được thực hiện.';
$lang['uploadbadcontent']      = 'Nội dung được tải lên không khớp với phần tập tin mở rộng %s.';
$lang['uploadspam']            = 'Việc tải lên đã bị chặn bởi danh sách đen về spam.';
$lang['uploadxss']             = 'Việc tải lên đã bị chặn do nội dung độc hại.';
$lang['uploadsize']            = 'Tập tin đã tải lên quá lớn. (tối đa %s)';
$lang['deletesucc']            = 'Đã xóa tập tin "%s".';
$lang['deletefail']            = 'Không thể xóa "%s" - kiểm tra quyền.';
$lang['mediainuse']            = 'Không thể xóa tập tin "%s" - nó vẫn đang được sử dụng.';
$lang['namespaces']            = 'Không gian tên';
$lang['mediafiles']            = 'Tập tin có sẵn trong';
$lang['accessdenied']          = 'Bạn không được phép xem trang này.';
$lang['mediausage']            = 'Sử dụng cú pháp sau để tham chiếu tập tin này:';
$lang['mediaview']             = 'Xem tập tin gốc';
$lang['mediaroot']             = 'gốc';
$lang['mediaupload']           = 'Tải một tập tin vào không gian tên hiện tại ở đây. Để tạo không gian tên con, hãy thêm chúng vào tên tập tin của bạn được phân tách bằng dấu hai chấm sau khi bạn chọn tập tin. Tập tin cũng có thể được chọn bằng cách kéo và thả.';
$lang['mediaextchange']        = 'Đã thay đổi phần mở rộng tập tin từ .%s thành .%s!';
$lang['reference']             = 'Tài liệu tham khảo cho';
$lang['ref_inuse']             = 'Không thể xóa tập tin này vì nó vẫn được sử dụng ở các trang sau:';
$lang['ref_hidden']            = 'Một số tài liệu tham khảo nằm trên các trang bạn không có quyền đọc';
$lang['hits']                  = 'Lượt truy cập';
$lang['quickhits']             = 'Tên trang trùng khớp';
$lang['toc']                   = 'Mục lục';
$lang['current']               = 'hiện tại';
$lang['yours']                 = 'Phiên bản của bạn';
$lang['diff']                  = 'Xem khác biệt với phiên bản hiện tại';
$lang['diff2']                 = 'Xem khác biệt giữa các phiên bản được chọn';
$lang['difflink']              = 'Liên kết đến bản xem so sánh này';
$lang['diff_type']             = 'Xem khác biệt:';
$lang['diff_inline']           = 'Nội tuyến';
$lang['diff_side']             = 'Cạnh nhau';
$lang['diffprevrev']           = 'Phiên bản trước';
$lang['diffnextrev']           = 'Phiên bản sau';
$lang['difflastrev']           = 'Phiên bản cuối';
$lang['diffbothprevrev']       = 'Phiên bản trước của cả hai bên';
$lang['diffbothnextrev']       = 'Phiên bản sau của cả hai bên';
$lang['line']                  = 'Dòng';
$lang['breadcrumb']            = 'Trang đã xem:';
$lang['youarehere']            = 'Bạn đang ở đây:';
$lang['lastmod']               = 'Sửa đổi lần cuối:';
$lang['by']                    = 'bởi';
$lang['deleted']               = 'đã bị xoá';
$lang['created']               = 'đã tạo';
$lang['restored']              = 'đã khôi phục phiên bản cũ (%s)';
$lang['external_edit']         = 'sửa đổi bên ngoài';
$lang['summary']               = 'Tóm lược sửa đổi';
$lang['noflash']               = 'Cần có <a href="http://get.adobe.com/flashplayer">Adobe Flash Plugin</a> mới có thể xem được nội dung này.';
$lang['download']              = 'Tải xuống đoạn trích';
$lang['tools']                 = 'Công cụ';
$lang['user_tools']            = 'Công cụ thành viên';
$lang['site_tools']            = 'Công cụ trang web';
$lang['page_tools']            = 'Công cụ trang';
$lang['skip_to_content']       = 'đi đến nội dung';
$lang['sidebar']               = 'Thanh bên';
$lang['mail_newpage']          = 'trang đã thêm:';
$lang['mail_changed']          = 'trang đã thay đổi:';
$lang['mail_subscribe_list']   = 'các trang đã thay đổi trong không gian tên:';
$lang['mail_new_user']         = 'thành viên mới:';
$lang['mail_upload']           = 'tập tin đã được tải lên:';
$lang['changes_type']          = 'Xem thay đổi của';
$lang['pages_changes']         = 'Trang';
$lang['media_changes']         = 'Tập tin phương tiện';
$lang['both_changes']          = 'Cả trang và tập tin phương tiện';
$lang['qb_bold']               = 'Chữ đậm';
$lang['qb_italic']             = 'Chữ nghiêng';
$lang['qb_underl']             = 'Chữ gạch chân';
$lang['qb_code']               = 'Chữ đơn cách';
$lang['qb_strike']             = 'Gạch ngang chữ';
$lang['qb_h1']                 = 'Đề mục cấp 1';
$lang['qb_h2']                 = 'Đề mục cấp 2';
$lang['qb_h3']                 = 'Đề mục cấp 3';
$lang['qb_h4']                 = 'Đề mục cấp 4';
$lang['qb_h5']                 = 'Đề mục cấp 5';
$lang['qb_h']                  = 'Đề mục';
$lang['qb_hs']                 = 'Chọn đề mục';
$lang['qb_hplus']              = 'Đề mục cao hơn';
$lang['qb_hminus']             = 'Đề mục thấp hơn';
$lang['qb_hequal']             = 'Đề mục cùng cấp';
$lang['qb_link']               = 'Liên kết nội bộ';
$lang['qb_extlink']            = 'Liên kết ngoài';
$lang['qb_hr']                 = 'Thanh ngang';
$lang['qb_ol']                 = 'Mục danh sách đánh số';
$lang['qb_ul']                 = 'Mục danh sách không đánh số';
$lang['qb_media']              = 'Thêm hình ảnh và các tập tin khác (mở trong một cửa sổ mới)';
$lang['qb_sig']                = 'Chèn chữ ký';
$lang['qb_smileys']            = 'Biểu tượng mặt cười';
$lang['qb_chars']              = 'Ký tự đặc biệt';
$lang['upperns']               = 'nhảy đến không gian tên mẹ';
$lang['metaedit']              = 'Sửa đổi siêu dữ liệu';
$lang['metasaveerr']           = 'Viết siêu dữ liệu không thành công';
$lang['metasaveok']            = 'Đã lưu siêu dữ liệu';
$lang['img_title']             = 'Tiêu đề:';
$lang['img_caption']           = 'Chú thích:';
$lang['img_date']              = 'Ngày:';
$lang['img_fname']             = 'Tên tập tin:';
$lang['img_fsize']             = 'Kích thước:';
$lang['img_artist']            = 'Người chụp:';
$lang['img_copyr']             = 'Bản quyền:';
$lang['img_format']            = 'Định dạng:';
$lang['img_camera']            = 'Máy ảnh:';
$lang['img_keywords']          = 'Từ khóa:';
$lang['img_width']             = 'Chiều rộng:';
$lang['img_height']            = 'Chiều cao:';
$lang['subscr_subscribe_success'] = 'Đã thêm %s vào danh sách đăng ký cho %s';
$lang['subscr_subscribe_error'] = 'Có lỗi khi thêm %s vào danh sách đăng ký cho %s';
$lang['subscr_subscribe_noaddress'] = 'Không có địa chỉ liên quan nào đến thông tin đăng nhập của bạn, bạn không thể thêm vào danh sách đăng ký';
$lang['subscr_unsubscribe_success'] = 'Đã xóa %s khỏi danh sách đăng ký cho %s';
$lang['subscr_unsubscribe_error'] = 'Có lỗi khi xóa %s khỏi danh sách đăng ký cho %s';
$lang['subscr_already_subscribed'] = '%s đã được đăng ký cho %s';
$lang['subscr_not_subscribed'] = '%s chưa được đăng ký cho %s';
$lang['subscr_m_not_subscribed'] = 'Bạn hiện chưa đăng ký vào trang hoặc không gian tên hiện tại.';
$lang['subscr_m_new_header']   = 'Thêm đăng ký';
$lang['subscr_m_current_header'] = 'Đăng ký hiện tại';
$lang['subscr_m_unsubscribe']  = 'Hủy đăng ký';
$lang['subscr_m_subscribe']    = 'Đăng ký';
$lang['subscr_m_receive']      = 'Nhận';
$lang['subscr_style_every']    = 'thư điện tử về mọi thay đổi';
$lang['subscr_style_digest']   = 'Thông báo thư điện tử về các thay đổi cho mỗi trang (mỗi %.2f ngày)';
$lang['subscr_style_list']     = 'danh sách các trang đã thay đổi kể từ thư điện tử cuối cùng (mỗi %.2f ngày)';
$lang['authtempfail']          = 'Xác thực thành viên tạm thời không có sẵn. Nếu tình trạng này vẫn còn, vui lòng thông báo cho Quản trị viên Wiki của bạn.';
$lang['i_chooselang']          = 'Chọn ngôn ngữ của bạn';
$lang['i_installer']           = 'Trình cài đặt DokuWiki';
$lang['i_wikiname']            = 'Tên Wiki';
$lang['i_enableacl']           = 'Kích hoạt Danh sách kiểm soát truy cập (ACL) (khuyến nghị)';
$lang['i_superuser']           = 'Siêu thành viên';
$lang['i_problems']            = 'Trình cài đặt tìm thấy một số vấn đề, được chỉ ra bên dưới. Bạn không thể tiếp tục cho đến khi bạn đã sửa chúng.';
$lang['i_modified']            = 'Vì lý do bảo mật, tập lệnh này sẽ chỉ hoạt động với bản cài đặt Dokuwiki mới và chưa được sửa đổi.
                                  Bạn nên trích xuất lại các tập tin từ gói đã tải xuống hoặc tham khảo
                    <a href="https://www.dokuwiki.org/install">Hướng dẫn cài đặt Dokuwiki</a> đầy đủ';
$lang['i_funcna']              = 'Hàm PHP <code>%s</code> không có sẵn. Có lẽ nhà cung cấp dịch vụ lưu trữ của bạn đã vô hiệu hóa nó vì một số lý do?';
$lang['i_disabled']            = 'Nó đã bị vô hiệu hóa bởi nhà cung cấp của bạn.';
$lang['i_funcnmail']           = '<b>Lưu ý:</b> Không có sẵn hàm PHP mail. %s Nếu nó vẫn không có sẵn, bạn có thể cài đặt <a href="https://www.dokuwiki.org/plugin:smtp">smtp plugin</a>.';
$lang['i_phpver']              = 'Phiên bản PHP <code>%s</code> hiện taị thấp hơn mức <code>%s</code> cần thiết. Bạn cần nâng cấp cài đặt PHP của bạn.';
$lang['i_mbfuncoverload']      = 'mbopes.func_overload phải bị vô hiệu trong php.ini để chạy DokuWiki.';
$lang['i_urandom']             = 'DokuWiki không thể tạo số mật mã an toàn cho cookie. Bạn có thể muốn kiểm tra cài đặt open_basingir trong php.ini để truy cập <code>/dev/urandom</code> thích hợp.';
$lang['i_permfail']            = 'DokuWiki không thể ghi được <code>%s</code>. Bạn cần sửa đổi các thiết lập quyền của đường dẫn này!';
$lang['i_confexists']          = '<code>%s</code> đã tồn tại';
$lang['i_writeerr']            = 'Không thể tạo <code>%s</code>. Bạn sẽ cần kiểm tra quyền truy cập thư mục/tập tin và tạo tập tin thủ công.';
$lang['i_badhash']             = 'Không thể công nhận hoặc sửa đổi dokuwiki.php (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - giá trị bất hợp pháp hoặc trống';
$lang['i_success']             = 'Đã hoàn thành việc cấu hình thành công. Bạn có thể xóa tập tin install.php ngay bây giờ. Tiếp tục với
                                 <a href="doku.php?id=wiki:welcome">DokuWiki mới của bạn</a>';
$lang['i_failure']             = 'Một số lỗi xảy ra trong khi viết tập tin cấu hình. Bạn có thể cần phải sửa chúng thủ công trước khi
                                  bạn có thể sử dụng <a href="doku.php?id=wiki:welcome">DokuWiki mới của bạn</a>.';
$lang['i_policy']              = 'Chính sách ACL (Danh sách kiểm soát truy cập) ban đầu';
$lang['i_pol0']                = 'Wiki mở (bất kỳ ai cũng có thể đọc, viết, tải lên)';
$lang['i_pol1']                = 'Wiki công cộng (bất kỳ ai cũng có thể xem, thành viên đã đăng ký có thể viết và tải lên)';
$lang['i_pol2']                = 'Wiki đóng (chỉ thành viên đã đăng ký mới có thể đọc, viết, tải lên)';
$lang['i_allowreg']            = 'Cho phép người dùng tự đăng ký';
$lang['i_retry']               = 'Thử lại';
$lang['i_license']             = 'Vui lòng chọn giấy phép bạn muốn đặt nội dung của bạn dưới:';
$lang['i_license_none']        = 'Không hiển thị bất kỳ thông tin giấy phép nào';
$lang['i_pop_field']           = 'Vui lòng giúp chúng tôi cải thiện trải nghiệm DokuWiki:';
$lang['i_pop_label']           = 'Mỗi tháng một lần, gửi dữ liệu sử dụng ẩn danh đến các nhà phát triển DokuWiki';
$lang['recent_global']         = 'Bạn hiện đang xem những thay đổi bên trong không gian tên <b>%s</b>. Bạn cũng có thể <a href="%s">xem những thay đổi gần đây trên toàn bộ wiki</a>.';
$lang['years']                 = '%d năm trước';
$lang['months']                = '%d tháng trước';
$lang['weeks']                 = '%d tuần trước';
$lang['days']                  = '%d ngày trước';
$lang['hours']                 = '%d giờ trước';
$lang['minutes']               = '%d phút trước';
$lang['seconds']               = '%d giây trước';
$lang['wordblock']             = 'Thay đổi của bạn không được lưu vì nó chứa văn bản bị chặn (spam).';
$lang['media_uploadtab']       = 'Tải lên';
$lang['media_searchtab']       = 'Tìm kiếm';
$lang['media_file']            = 'Tập tin';
$lang['media_viewtab']         = 'Xem';
$lang['media_edittab']         = 'Sửa đổi';
$lang['media_historytab']      = 'Lịch sử';
$lang['media_list_thumbs']     = 'Hình thu nhỏ';
$lang['media_list_rows']       = 'Dòng';
$lang['media_sort_name']       = 'Tên';
$lang['media_sort_date']       = 'Ngày';
$lang['media_namespaces']      = 'Chọn không gian tên';
$lang['media_files']           = 'Tập tin trong %s';
$lang['media_upload']          = 'Tải lên %s';
$lang['media_search']          = 'Tìm kiếm trong %s';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s ở %s';
$lang['media_edit']            = 'Sửa đổi %s';
$lang['media_history']         = 'Lịch sử của %s';
$lang['media_meta_edited']     = 'đã sửa siêu dữ liệu';
$lang['media_perm_read']       = 'Xin lỗi, bạn không có đủ quyền để đọc tập tin.';
$lang['media_perm_upload']     = 'Xin lỗi, bạn không đủ quyền để tải tập tin lên.';
$lang['media_update']          = 'Tải lên phiên bản mới';
$lang['media_restore']         = 'Phục hồi phiên bản này';
$lang['media_acl_warning']     = 'Danh sách này có thể không đầy đủ do các hạn chế về Danh sách kiểm soát truy cập (ACL) và trang ẩn.';
$lang['email_fail']            = 'Thiếu hoặc đã vô hiệu hóa PHP mail(). Những thư điện tử sau không được gửi:';
$lang['currentns']             = 'Không gian tên hiện tại';
$lang['searchresult']          = 'Kết quả tìm kiếm';
$lang['plainhtml']             = 'HTML thuần túy';
$lang['wikimarkup']            = 'Đánh dấu Wiki';
$lang['page_nonexist_rev']     = 'Trang không tồn tại tại %s. Sau đó, nó đã được tạo ở <a href="%s">%s</a>.';
$lang['unable_to_parse_date']  = 'Không thể phân tích cú pháp tại tham số "%s".';
$lang['email_signature_text']  = 'Thư này được tạo bởi DokuWiki tại
@DOKUWIKIURL@';
